package einfacherpop3client;

/**
 * Title:        Einfacher POP3 Client
 * Description:  Zusammenstellung aller Beispiele aus dem Skript zum Aufbau eines einfachen POP3 Clients
 * Copyright:    Copyright (c) 2000
 * Company:      Joller-Voss GmbH
 * @author J.M.Joller
 * @version 1.0
 */

import javax.mail.*;
import javax.mail.internet.*;
import java.util.*;
import java.io.*;


public class POP3Client {

  public static void main(String[] args) {

    Properties props = new Properties();

    String host = "mail.swissonline.ch";
    String username = "josef.m.joller";
    String password = "**************";
    String provider = "pop3";

    try {

      // Verbindungsaufbau zum POP3 Server
      Session session = Session.getDefaultInstance(props, null);
      Store store = session.getStore(provider);
      store.connect(host, username, password);

      // Folder ffnen
      Folder inbox = store.getFolder("INBOX");
      if (inbox == null) {
        System.out.println("No INBOX");
        System.exit(1);
      }
      inbox.open(Folder.READ_ONLY);

      // Nachrichten lesen
      Message[] messages = inbox.getMessages();
      for (int i = 0; i < messages.length; i++) {
        System.out.println("------------ Message " + (i+1)
         + " ------------");
        messages[i].writeTo(System.out);
      }

      // Verbindungsabbau
      // Nachrichten bleiben auf dem Server
      inbox.close(false);
      store.close();

    }
    catch (Exception e) {
      e.printStackTrace();
    }

  }

  public static void printMessage(Message m) throws Exception {

    // Header ausdrucken
    Address[] from = m.getFrom();
    if (from != null) {
      for (int i = 0; i < from.length; i++) {
        System.out.println("From: " + from[i]);
      }
    }

    Address[] to = m.getRecipients(Message.RecipientType.TO);
    if (to != null) {
      for (int i = 0; i < to.length; i++) {
        System.out.println("To: " + to[i]);
      }
    }

    String subject = m.getSubject();
    if (subject != null) {
      System.out.println("Subject: " + subject);
    }

    Date d = m.getSentDate();
    if (d != null) {
      System.out.println("Date: " + d);
    }

    // Leerzeile als Trennung
    System.out.println();

    // Message Body
    Object content = m.getContent();
    if (content instanceof String) {
      System.out.println(content);
    }
    else if (content instanceof InputStream) {
      InputStream in = (InputStream) content;
      int c;
      while ((c = in.read()) != -1) System.out.write(c);
    }
    else {
      //  multi-part MIME
      //  fhrt zu einem Fehler
      System.out.println("Content Type Fehler");
    }

  }

}